@@ -7,7 +7,6 @@ from pytest_idempotent import idempotent
 
 @idempotent()
 def func(x: list[int]) -> None:
-    """Correctly Idempotent."""
     if not x:
         x += [9]
 
@@ -23,7 +22,7 @@ class TestVariousFunctions:
         assert x == [9]
 
     @staticmethod
-    @pytest.mark.idempotent(run_twice=False)
+    @pytest.mark.idempotent(enabled=False)
     def test_func_without_idempotency_check() -> None:
         x: list[int] = []
 
@@ -41,7 +40,7 @@ class TestVariousFunctions:
         assert x == [9]
 
     @staticmethod
-    @pytest.mark.idempotent(run_twice=True)
+    @pytest.mark.idempotent(enabled=True)
     def test_func_with_double_idempotency_enabled() -> None:
         x: list[int] = []
 
